==> ultraman-starter-1.1.8-sources.jar: com/xforceplus/ultraman/starter/autoconfigure/UltramanMetadataAutoConfiguration.java <==
package com.xforceplus.ultraman.starter.autoconfigure;

import com.typesafe.config.ConfigList;
import com.xforceplus.metadata.schema.runtime.MetadataEngine;
import com.xforceplus.metadata.schema.utils.MetadataEngineHolder;
import com.xforceplus.ultraman.metadata.engine.EntityClassEngine;
import com.xforceplus.ultraman.metadata.engine.impl.EntityClassEngineImpl;
import com.xforceplus.ultraman.metadata.repository.MetadataRepository;
import com.xforceplus.ultraman.metadata.repository.impl.GraphBasedMetadataRepository;
import com.xforceplus.ultraman.sdk.infra.base.ExecutionConfig;
import org.apache.tinkerpop.gremlin.server.GremlinServer;
import org.apache.tinkerpop.gremlin.server.Settings;
import org.apache.tinkerpop.gremlin.server.util.ServerGremlinExecutor;
import org.janusgraph.core.JanusGraph;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;

@ConditionalOnProperty(value = "xplat.oqsengine.sdk.enabled", matchIfMissing = true)
public class UltramanMetadataAutoConfiguration {

    /**
     * TODO
     * @return
     */
    @Bean
    public MetadataRepository metadataRepository() {
        return new GraphBasedMetadataRepository();
    }

    @Bean
    public MetadataEngine ultramanMetadataEngine(ExecutionConfig config) throws Exception {
        Settings settings = Settings.read(getClass().getResourceAsStream("/gremlin-server-configuration.yaml"));
        settings.graphs.put("graph", "inmemory");
        settings.port = config.getMetadataPort();
        ServerGremlinExecutor join = new GremlinServer(settings).start().join();

        JanusGraph graph = (JanusGraph)join.getGraphManager().getGraph("graph");
        join.getGraphManager().putTraversalSource("g", graph.traversal());

        MetadataEngineHolder.graph(graph);
        MetadataEngineHolder.init();
        return MetadataEngineHolder.get();
    }

    @Bean
    public EntityClassEngine entityClassEngine(MetadataEngine metadataEngine){
        return new EntityClassEngineImpl(metadataEngine);
    }
}

==> ultraman-starter-1.1.22-sources.jar: com/xforceplus/ultraman/starter/autoconfigure/UltramanMetadataAutoConfiguration.java <==
package com.xforceplus.ultraman.starter.autoconfigure;

import com.typesafe.config.ConfigList;
import com.xforceplus.metadata.schema.runtime.MetadataEngine;
import com.xforceplus.metadata.schema.utils.MetadataEngineHolder;
import com.xforceplus.ultraman.metadata.engine.EntityClassEngine;
import com.xforceplus.ultraman.metadata.engine.impl.EntityClassEngineImpl;
import com.xforceplus.ultraman.metadata.repository.MetadataRepository;
import com.xforceplus.ultraman.metadata.repository.impl.GraphBasedMetadataRepository;
import com.xforceplus.ultraman.sdk.infra.base.ExecutionConfig;
import org.apache.tinkerpop.gremlin.server.GremlinServer;
import org.apache.tinkerpop.gremlin.server.Settings;
import org.apache.tinkerpop.gremlin.server.util.ServerGremlinExecutor;
import org.janusgraph.core.JanusGraph;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;

@ConditionalOnProperty(value = "xplat.oqsengine.sdk.enabled", matchIfMissing = true)
public class UltramanMetadataAutoConfiguration {

    /**
     * TODO
     * @return
     */
    @Bean
    public MetadataRepository metadataRepository() {
        return new GraphBasedMetadataRepository();
    }

    @Bean
    public MetadataEngine ultramanMetadataEngine(ExecutionConfig config) throws Exception {
        JanusGraph graph = null;
        if(config.isMetadataEnabled()) {
            Settings settings = Settings.read(getClass().getResourceAsStream("/gremlin-server-configuration.yaml"));
            settings.graphs.put("graph", "inmemory");
            settings.port = config.getMetadataPort();
            ServerGremlinExecutor join = new GremlinServer(settings).start().join();
            graph = (JanusGraph)join.getGraphManager().getGraph("graph");
            join.getGraphManager().putTraversalSource("g", graph.traversal());
        }

        MetadataEngineHolder.graph(graph);
        MetadataEngineHolder.init();
        return MetadataEngineHolder.get();
    }

    @Bean
    public EntityClassEngine entityClassEngine(MetadataEngine metadataEngine){
        return new EntityClassEngineImpl(metadataEngine);
    }
}
